import type CSS from "./css";
import type HTML from "./html";
import type IMG from "./img";
import type JS from "./js";
import type SVG from "./svg";

export type filterFunction = (file: string) => boolean;

export interface Options {
	[key: string]: any;

	path?: string;

	filter?:
		| string
		| RegExp
		| filterFunction
		| [string]
		| [RegExp]
		| [filterFunction];

	css?: boolean | CSS;

	html?: boolean | HTML;

	js?: boolean | JS;

	img?: boolean | IMG;

	svg?: boolean | SVG;

	logger?: number;
}

export default (): Options => ({
	path: "./dist/",
	css: {
		clone: false,
		comments: false,
		forceMediaMerge: true,
	},
	html: {
		caseSensitive: true,
		collapseInlineTagWhitespace: false,
		collapseWhitespace: true,
		continueOnParseError: true,
		html5: true,
		includeAutoGeneratedTags: true,
		keepClosingSlash: true,
		minifyCSS: true,
		minifyJS: true,
		minifyURLs: false,
		preventAttributesEscaping: false,
		processConditionalComments: true,
		removeAttributeQuotes: true,
		removeComments: false,
		removeScriptTypeAttributes: true,
		removeStyleLinkTypeAttributes: true,
		removeTagWhitespace: false,
		sortAttributes: true,
		sortClassName: true,
		trimCustomFragments: true,
		useShortDoctype: false,
		noNewlinesBeforeTagClose: true,
		quoteCharacter: '"',
	},
	js: {
		ecma: 5,
		enclose: false,
		keep_classnames: false,
		keep_fnames: false,
		ie8: false,
		module: false,
		safari10: false,
		toplevel: false,
	},
	img: {
		avif: {
			chromaSubsampling: "4:4:4",
			effort: 9,
		},
		gif: {
			effort: 10,
		},
		jpeg: {
			chromaSubsampling: "4:4:4",
			mozjpeg: true,
			trellisQuantisation: true,
			overshootDeringing: true,
			optimiseScans: true,
		},
		png: {
			compressionLevel: 9,
			palette: true,
		},
		raw: {},
		tiff: {
			compression: "lzw",
		},
		webp: {
			effort: 6,
		},
	},
	svg: {
		multipass: true,
		js2svg: {
			indent: 0,
			pretty: false,
		},
		plugins: ["preset-default"],
	},
	logger: 2,
});
